// 023 u_c_vcl_net_log
// 17 sep 2007

// -- (C) Felix John COLIBRI 2007
// -- documentation: http://www.felix-colibri.com

(*$r+*)

// -- todo: concatenate with the previous

unit u_c_vcl_net_log;
  interface
    uses Classes;

    type c_log= class
                  m_c_log_stream: tFileStream;
                  m_name, m_file_name: String;
                  // m_do_log: Boolean;
                  // m_concatenate_to_previous: Boolean;

                  constructor create_log(p_name, p_file_name: String);

                  procedure write_string(p_text: String);
                  procedure write_line(p_text: String);
                  procedure write_strings(p_title: String; p_strings: tStrings);

                  destructor Destroy; Override;
                end; // c_log

  implementation
    uses SysUtils, Dialogs, FileCtrl, Forms
        , Windows
        , u_vcl_net_types_constants, u_vcl_net_characters;

    constructor c_log.create_log(p_name, p_file_name: String);
      var l_path: String;
      begin
        Inherited Create;
        
        m_name:= p_name;
        m_file_name:= p_file_name;

        // -- if the file name is relative, add the Application path
        l_path:= ExtractFilePath(m_file_name);
        if (Length(l_path)< 2) or  (l_path[2]<> ':')
          then begin
              l_path:= ExtractFilePath(Application.ExeName)+ l_path;
              m_file_name:= l_path+ ExtractFileName(p_file_name);
            end;

        // m_do_log:= True;

        // -- concatenate log

        // -- create the file
        if Not DirectoryExists(ExtractFilePath(m_file_name))
          then begin
              // bug_halt('log could not create '+ p_file_name);
              ShowMessage('BUG no path '+ ExtractFilePath(m_file_name)+ '. Halt.');
              Halt(55);
            end;

(*
        Assign(m_c_log_stream, m_file_name);
        Rewrite(m_c_log_stream);
        Close(m_c_log_stream);
*)
        m_c_log_stream:= tFileStream.Create(m_file_name, fmCreate or fmOpenWrite);
        m_c_log_stream.Free;

        // -- the date
        write_line('// -- '+ m_file_name+ ' '+ DateTimeToStr(Now));
      end; // create_log

    procedure c_log.write_string(p_text: String);
      // var l_length: Integer;
      var l_index: Integer;
      begin
(*
        Reset(m_c_log_stream, 1);
        Seek(m_c_log_stream, FileSize(m_c_log_stream));
        BlockWrite(m_c_log_stream, p_text[1], Length(p_text));
        Close(m_c_log_stream);
*)
        if Length(p_text)= 0
          then Exit;

        m_c_log_stream:= tFileStream.Create(m_file_name, fmOpenWrite);
        with m_c_log_stream do
        begin
          // -- go to end of line
          Position:= Size;

          // -- write the string

          // -- ?? does not work (only flushes the first character. Unicode pb ?
          // WriteBuffer(p_text[1], Length(p_text));
          for l_index:= 1 to Length(p_text) do
            Write(p_text[l_index], 1);

          Free;
        end; // with m_c_log_stream
      end; // write_string

    procedure c_log.write_line(p_text: String);
      begin
        p_text:= p_text+ k_return_line_feed;
        // ShowMessage(m_file_name+ IntToStr(Integer(Self)));

        // -- if used DirectoryListbox.Directory, with a wrong name, bombs here
        if not FileExists(m_file_name)
          then ShowMessage('c_log.no '+ m_file_name+ '|');

        // ShowMessage(GetCurrentDir+ ' '+ m_file_name);
        // Assign(m_c_log_stream, m_file_name);
        write_string(p_text);
(*
        Reset(m_c_log_stream, 1);
        Seek(m_c_log_stream, FileSize(m_c_log_stream));
        BlockWrite(m_c_log_stream, p_text[1], Length(p_text));
        Close(m_c_log_stream);
*)
      end; // write_line

    procedure c_log.write_strings(p_title: String; p_strings: tStrings);
      var l_line: Integer;
      begin
        if p_strings= nil
          then write_line(p_title+ ' Strings NIL')
          else
            if p_strings.Count= 0
              then write_line(p_title+ ' = empty')
              else
                for l_line:= 0 to p_strings.Count- 1 do
                  write_line(p_title+ ' '+ IntToStr(l_line)+ '= '+ p_strings[l_line]);
      end; // write_strings

    destructor c_log.Destroy;
      begin
        // Inherited Destroy;
      end; // Destroy

    // -- global

    begin // u_c_log
    end. // u_c_log


